Learn R Programming

outstandR (version 1.0.0)

BC_ALD_contY_mixedX: Aggregate level patient data for continuous outcome, mixed covariates

Description

This data set contains summaries of simulated patient covariate and outcome values. Corresponds to IPD data set.

Usage

data(BC_ALD_contY_mixedX)

Arguments

Format

y ~ X1 + X3 + X4 + trt + trt:(X2 + X3 + X4)

variable

String covariate or outcome name. From X1, X2, X3, X4, y.

statistic

String summary statistic name. From mean, sd, prob, sum, N

value

Numeric value

trt

Treatment (arm) name. From B, C

References

Remiro‐Azocar A, Heath A, Baio G (2022)