powered by
Computes the average treatment effect (ATE) based on the specified effect scale.
calculate_ate(mean_comp, mean_ref, effect)
Numeric computed average treatment effect on the specified scale.
Mean of the outcome for the comparator and reference / common
A character string specifying the effect scale. Options are:
Log-odds difference.
Risk difference.
Probit scale difference (z-scores).
Log relative risk for rare events.
Log relative risk.
calculate_ate(mean_comp = 0.7, mean_ref = 0.5, effect = "log_odds") calculate_ate(mean_comp = 0.7, mean_ref = 0.5, effect = "risk_difference")
Run the code above in your browser using DataLab