Learn R Programming

outstandR (version 1.0.0)

outstandR-package: outstandR: Model-Based Standardisation for Indirect Treatment Comparison with Limited Subject-Level Data

Description

For the problem of indirect treatment comparison with limited subject-level data, this package provides tools for model-based standardisation with several different computation approaches. See Remiro‐Azócar A, Heath A, Baio G (2022) "Parametric G‐computation for compatible indirect treatment comparisons with limited individual patient data", Res. Synth. Methods, 1–31. ISSN 1759-2879, tools:::Rd_expr_doi("10.1002/jrsm.1565").

Arguments

Author

Maintainer: Nathan Green n.green@ucl.ac.uk (ORCID) (ROR) [copyright holder]

Authors:

See Also